
# Mapper Methods

::: fliq.query.Query
    options:
        filters: [
            "^append$", "^append_many$", "^bottom$", "^distinct$", "^exclude$", "^flatten$", "^group_by$", "^interleave$", "^order$", "^prepend$", "^prepend_many$", "^reverse$", "^select$", "^shuffle$", "^skip$", "^slice$", "^take$", "^top$", "^where$", "^zip$" 
        ]   
